@@ -91,10 +91,18 @@ class MarkdownExtraDataPlugin(BasePlugin):
                         ),
                     )
 
-    def on_page_markdown(self, markdown, config, **kwargs):
-        context = {key: config.get(key) for key in CONFIG_KEYS if key in config}
-        context.update(config.get("extra", {}))
+    # Apply template substitution to both page content and title
+    def on_page_markdown(self, markdown, page, **kwargs):
+        page.title = self.apply_template(page.title)
+        return self.apply_template(markdown)
+
+    # Initialize this mkdocs config and Jinja2 env
+    def on_config(self, mkdocsConfig, **kwargs):
         jinja_options = self.config[self.JINJA_OPTIONS]
-        env = jinja2.Environment(undefined=jinja2.DebugUndefined, **jinja_options)
-        md_template = env.from_string(markdown)
-        return md_template.render(**config.get("extra"))
+        self.env = jinja2.Environment(undefined=jinja2.DebugUndefined, **jinja_options)
+        self.mkdocsConfig = mkdocsConfig
+
+    # Apply Jinja2 substitution to specified string
+    def apply_template(self, template_string):
+        md_template = self.env.from_string(template_string)
+        return md_template.render(**self.mkdocsConfig.get("extra"))
